# SQLython

SQLython is a Python library that allows you to write SQL queries in Python. It is designed to be a simple and
easy-to-use tool for working with SQL databases in Python. Inspired by Eloquent in Laravel.